# vercel_blob

A Python wrapper for the Vercel Blob Storage API

## Installation


```
pip3 install vercel_blob
```

## Getting Started

### Python Version

This package (vercel_blob) was written using Python 3 in mind, and Python 2 will not work properly.

### Set Environment Variable for Authorization

```
export BLOB_READ_WRITE_TOKEN="superssecretkey"
```

### Add vercel_blob to your code

```

```

## Using vercel_blob

Currently only supports the basic list, put, delete and head(get file metadata) operations. Here's a quick overview:

### Upload File / Blob to the Storage
```

```

### List all files in the Blob Storage
```

```

### Delete a blob or a list of blobs from the Blob Storage
```

```

### Get blob metadata
```

```